ewa.audio

Package ewa :: Module audio |
[hide private]
[frames] | no frames]

# Module audio

source code

    This module is responsible for managing audio files:

      * managing the main (content) audio files, located in
        <audioroot>/main/path/to/audiofile
      * managing extra audio files, located in
        <audioroot/extra, in two subdirectories,
        <audioroot/extra/masters and <audioroot/extra/transcoded.
      * resolving audiofile symbolic names to files within
        the managed hierarchy.
      * creating combined (spliced) files according to rules passed
        in.

Classes | [hide private]
| AudioProviderException
| FileNotFound
| BaseAudioProvider
| FSAudioProvider
| StreamAudioProvider

Functions | [hide private]
is_original(s) | source code

Variables | [hide private]
| __package__ = ``'``ewa``'``